package com.muyu.server.controller;

import com.muyu.common.core.domain.Result;
import com.muyu.common.domain.Connect;
import com.muyu.server.service.ConnectService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.media.Schema;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.AllArgsConstructor;
import org.springframework.util.CollectionUtils;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @Author：yang
 * @Package：com.muyu.server.controller
 * @Project：cloud-property
 * @name：ConnectReqController 配置控制层
 * @Date：2024/8/25 16:12
 */
@RestController
@RequestMapping("/connect")
@Tag(name = "查询数据",description = "从配置表查询数据")
@AllArgsConstructor
public class ConnectController {

    private final ConnectService connectService;


    /**
     * 查询配置表
     * @param connect 配置列表请求参数
     * @return 返回试图
     */
    @PostMapping("/selectConnect")
    @Operation(summary = "查询数据",description = "查询数据")
    public Result<List<Connect>> selectConnect(
            @Validated @RequestBody Connect connect
    ){
        List<Connect> connects = connectService.selectConnect(connect);
        if (!CollectionUtils.isEmpty(connects)){
            return Result.success(connects,"查询成功");
        }
        return Result.success(null,"暂无数据");
    }

    /**
     * 添加方法
     * @param connect 响应配置信息
     * @return 返回结果
     */
    @PostMapping("/add")
    @Operation(summary = "添加配置表",description = "添加配置信息，添加添加成功之后才可以使用配置类的产品")
    public Result<Integer> save(
            @Validated @RequestBody Connect connect
    ){
        return connectService.save(connect)
                ?Result.success(200,"添加成功")
                :Result.success(500,"添加失败");
    }

    /**
     * 修改方法
     * @param connect 响应配置信息
     * @return 返回结果
     */
    @PutMapping("/upd")
    @Operation(summary = "修改方法",description = "根据ID进行修改配置信息")
    public Result<Integer> update(
            @Schema(title = "配置ID",type = "Integer",defaultValue = "1",description = "修改配置需要唯一条件")
            @Validated @RequestBody Connect connect
    ){
        return connectService.updateById(connect)
                ?Result.success(200,"修改成功")
                :Result.success(500,"修改失败");
    }

    /**
     * 删除配置信息
     * @param id 请求ID
     * @return 返回结果
     */
    @DeleteMapping("/del/{id}")
    @Operation(summary = "客户信息删除",description = "通过ID删除客户信息")
    public Result<Integer> delete(@PathVariable("id") Integer id){
        return connectService.removeById(id)
                ?Result.success(200,"删除成功")
                :Result.error(500,"删除失败");
    }

    /**
     * 通过ID改变初始化状态 将可以被初始化
     * @param id 响应ID
     * @return 返回结果
     */
    @GetMapping("/updInitDisable/{id}")
    @Operation(summary = "通过ID改变初始化状态",description = "通过ID改变初始化后，将可以被初始化")
    public Result<Integer> updInitDisable(
            @PathVariable Integer id){

        return connectService.updInitDisable(id)
                ?Result.success(200,"更改成功")
                :Result.success(500,"更改失败");
    }

    /**
     * 通过ID改变初始化状态 将不再被初始化
     * @param id 响应ID
     * @return 返回结果
     */
    @GetMapping("/updInitEnable/{id}")
    @Operation(summary = "通过ID改变初始化状态",description = "通过ID改变初始化后，将不再被初始化")
    public Result<Integer> updInitEnable(
            @PathVariable Integer id){

        return connectService.updInitEnable(id)
                ?Result.success(200,"更改成功")
                :Result.success(500,"更改失败");
    }

    /**
     * 测试接口
     * @param connect 响应ID
     * @return 返回结果
     */
    @PostMapping("/text")
    @Operation(summary = "测试接口",description = "测试接口")
    public Result<Integer> text(
            @Validated @RequestBody Connect connect
    ){

        return connectService.text(connect)
                ?Result.success(200,"测试成功")
                :Result.success(500,"测试失败");
    }
}
